#!/usr/bin/env python3

import setuptools

setuptools.setup(
  name = 'browserpot-bridge',
  version = '0.0.1',
  description = '',
  author = 'browserpot',
  author_email = 'browserpot@gmail.com',
  license = 'GPL-3.0',
  url = 'https://github.com/browserpot/browserpot-bridge',
  download_url = 'https://github.com/browserpot/browserpot-bridge/downloads',
  keywords = ['browserpot'],
  classifiers = [],
  packages = setuptools.find_packages(),
)
